.. Copyright 2016 IBM Corp. All Rights Reserved.
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
..    http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..

.. _`Concepts`:

Concepts
========

TODO: Write up some concepts:

- Topology with client, HMC and managed CPCs
- CPCs that are visible vs. not visible
- Visibility dependent on access rights of the userid
- Connecting to the HMC, and session vs. client
- Failure handling
- Dependency on CPC mode (classic, DPM, ensemble)
- Basics about resource model

  - How managers and resources play together
  - Description of resource properties in HMC API book
  - Mapping between data types used in the HMC API book and Python data types
    used to represent them.
